import { Link } from "wouter";
import { scrollToTop } from "@/lib/scroll-utils";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import { useQuery } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { useState } from "react";
import { SEOHead } from "@/components/seo-head";
import { pageMetadata } from "@/lib/seo-data";

import Navbar from "@/components/navbar";
import { useAuth } from "@/lib/auth.tsx";
import { 
  Crown, 
  CheckCircle, 
  X,
  Calendar,
  CreditCard,
  Shield,
  Clock,
  Download,
  Heart,
  Users,
  Sparkles,
  ArrowRight,
  AlertCircle,
  ArrowLeft,
  Gift,
  Headphones
} from "lucide-react";

interface UserData {
  id: number;
  username: string;
  email: string;
  subscriptionTier: string;
  isSubscribed: boolean;
  freeStoriesUsed: number;
  monthlyStoriesUsed: number;
  monthlyStoriesRemaining: number;
  billingCycleStart?: string;
  subscriptionEndsAt?: string;
}

export default function Pricing() {
  const { user } = useAuth();
  const { toast } = useToast();
  const [showCreditError, setShowCreditError] = useState(false);

  const { data: userData } = useQuery<UserData>({
    queryKey: ['/api/user'],
    enabled: !!user,
  });

  const handleCreditClick = (e: React.MouseEvent) => {
    e.preventDefault();
    
    if (!user) {
      // Redirect to login for unauthenticated users
      window.location.href = '/login';
      return;
    }
    
    if (userData?.subscriptionTier === 'free') {
      // Show error and scroll to subscription options
      setShowCreditError(true);
      toast({
        title: "Subscription Required",
        description: "Only Premium and Ultimate subscribers can purchase extra credits. Upgrade now to access the credit system.",
        variant: "destructive",
        duration: 6000,
      });
      
      // Scroll to subscription section
      setTimeout(() => {
        const subscriptionSection = document.getElementById('subscription-plans');
        if (subscriptionSection) {
          subscriptionSection.scrollIntoView({ 
            behavior: 'smooth',
            block: 'center'
          });
        }
      }, 500);
      return;
    }
    
    // For Premium/Ultimate users, proceed to buy credits
    window.location.href = '/buy-credits';
  };

  return (
    <div className="min-h-screen bg-gradient-to-br from-brand-cream via-white to-brand-teal/10">
      <SEOHead 
        title={pageMetadata.pricing.title}
        description={pageMetadata.pricing.description}
        keywords={pageMetadata.pricing.keywords}
      />
      <Navbar />

      {/* Hero Section */}
      <section className="py-16">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <Link href="/" onClick={scrollToTop}>
            <Button variant="ghost" className="mb-6 text-brand-blue hover:text-brand-blue/80">
              <ArrowLeft className="w-4 h-4 mr-2" />
              Back to Home
            </Button>
          </Link>
          <div className="mb-8">
            <h1 className="title-main text-4xl lg:text-5xl text-brand-blue mb-6">
              Choose Your Subscription Plan
            </h1>
            <p className="body-text text-brand-orange mb-6 font-semibold text-xl sm:text-2xl lg:text-3xl leading-relaxed">
              Every story is an investment in your child's imagination.
            </p>
            <p className="body-text text-lg sm:text-xl lg:text-2xl text-brand-blue mb-4 leading-relaxed max-w-3xl mx-auto">
              Start with 2 free stories a month with basic features, upgrade to Premium for enhanced features, or go Ultimate for full audio narration.
            </p>
          </div>
        </div>
      </section>



      {/* Pricing Cards */}
      <section id="subscription-plans" className="py-16">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid md:grid-cols-3 gap-12 md:gap-10 space-y-16 md:space-y-0">
            {/* Free Plan */}
            <Card className="cloud-shape border-2 border-brand-teal/30 relative shadow-xl hover:shadow-2xl transition-all duration-300 transform hover:scale-105 flex flex-col h-full">
              <CardContent className="p-10 flex flex-col h-full">
                <div className="text-center mb-8">
                  <div className="w-16 h-16 mx-auto mb-4 bg-brand-aqua/20 rounded-full flex items-center justify-center">
                    <Gift className="w-8 h-8 text-brand-blue" />
                  </div>
                  <h3 className="title-secondary text-3xl mb-3 text-brand-blue">Free Trial</h3>
                  <div className="text-5xl font-bold mb-2 text-brand-blue">£0</div>
                  <p className="body-text text-brand-blue">2 free stories per month</p>
                </div>

                <ul className="space-y-4 mb-10 flex-grow">
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">2 personalised stories per month</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">Basic customisation</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">PDF download</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">No payment details required</span>
                  </li>
                </ul>

                <div className="mt-auto">
                  <Link href="/login?tab=register" onClick={scrollToTop}>
                    <Button className="btn-free w-full py-4 text-xl rounded-full">
                      Try Free Story
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>

            {/* Premium Plan */}
            <Card className="cloud-shape border-2 border-[hsl(var(--premium-gradient-start))] relative shadow-2xl transform hover:scale-105 transition-all duration-300 flex flex-col h-full">
              <div className="absolute -top-4 left-1/2 transform -translate-x-1/2">
                <Badge className="bg-gradient-to-r from-[hsl(var(--premium-gradient-start))] to-[hsl(var(--premium-gradient-end))] text-white px-6 py-2 text-sm font-semibold rounded-full shadow-lg">
                  Read
                </Badge>
              </div>

              <CardContent className="p-10 flex flex-col h-full">
                <div className="text-center mb-8">
                  <div className="w-16 h-16 mx-auto mb-4 bg-[hsl(var(--premium-gradient-start))]/20 rounded-full flex items-center justify-center">
                    <Crown className="w-8 h-8 text-brand-blue" />
                  </div>
                  <h3 className="title-secondary text-3xl mb-3 text-brand-blue">Premium</h3>
                  <div className="text-5xl font-bold mb-2 text-brand-blue">£2.99</div>
                  <p className="body-text text-brand-blue">per month</p>
                </div>

                <ul className="space-y-4 mb-10 flex-grow">
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">10 stories per month</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">Personal story library (50 stories)</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">Supporting characters</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">Phonics Focussed Reading</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">Dyslexia-friendly format</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">All story lengths</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">Story library</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">PDF downloads</span>
                  </li>
                </ul>

                <div className="mt-auto">
                  <Link href="/subscribe" onClick={scrollToTop}>
                    <Button className="btn-premium w-full py-4 text-xl shadow-lg hover:shadow-xl transition-all duration-300 rounded-full font-semibold">
                      <Crown className="w-5 h-5 mr-2" />
                      Start Premium
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>

            {/* Ultimate Plan */}
            <Card className="cloud-shape border-2 border-brand-orange relative shadow-xl hover:shadow-2xl transition-all duration-300 transform hover:scale-105 flex flex-col h-full">
              <div className="absolute -top-4 left-1/2 transform -translate-x-1/2">
                <Badge className="bg-gradient-to-r from-brand-orange to-brand-orange/80 text-white px-6 py-2 text-sm font-semibold rounded-full shadow-lg whitespace-nowrap">
                  Read and Listen
                </Badge>
              </div>
              <CardContent className="p-10 flex flex-col h-full">
                <div className="text-center mb-8">
                  <div className="w-16 h-16 mx-auto mb-4 bg-brand-orange/20 rounded-full flex items-center justify-center">
                    <Headphones className="w-6 h-6" />
                  </div>
                  <h3 className="title-secondary text-3xl mb-3 text-brand-blue">Ultimate</h3>
                  <div className="text-5xl font-bold mb-2 text-brand-blue">£3.99</div>
                  <p className="body-text text-brand-blue">per month</p>
                </div>

                <ul className="space-y-4 mb-10 flex-grow">
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">All Premium Features</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">AI voice narration</span>
                  </li>
                  <li className="flex items-center">
                    <CheckCircle className="w-6 h-6 text-brand-aqua mr-4" />
                    <span className="body-text text-brand-blue">MP3 audio downloads</span>
                  </li>
                </ul>

                <div className="mt-auto">
                  <Link href="/subscribe?plan=ultimate" onClick={scrollToTop}>
                    <Button className="btn-ultimate w-full py-4 text-xl shadow-lg hover:shadow-xl transition-all duration-300 rounded-full font-semibold">
                      <Headphones className="w-5 h-5 mr-2" />
                      Start Ultimate
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Top-up Credits Section */}
      <section className="py-16 bg-gradient-to-br from-brand-cream to-white">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="title-primary text-3xl lg:text-4xl text-brand-blue mb-4">
              Need Extra Stories?
            </h2>
            <p className="body-text text-lg text-brand-orange max-w-2xl mx-auto">
              Premium and Ultimate subscribers can purchase top-up credits when they exceed their monthly limits. Credits never expire and provide features matching your subscription tier.
            </p>
          </div>

          {/* Credit Pricing */}
          <Card className="cloud-shape bg-white border-2 border-brand-blue/20">
            <CardHeader className="text-center">
              <CardTitle className="text-2xl text-brand-blue">Credit Pricing</CardTitle>
              <p className="text-brand-blue/70">One-time purchases that never expire</p>
            </CardHeader>
            <CardContent>
              <div className="grid sm:grid-cols-3 gap-6">
                <div onClick={handleCreditClick} className="text-center p-4 bg-brand-cream rounded-xl cursor-pointer transition-all hover:shadow-lg hover:scale-105 hover:bg-brand-cream/80">
                  <h4 className="font-bold text-brand-blue text-lg">5 Credits</h4>
                  <p className="text-brand-blue text-2xl font-bold">£4.99</p>
                  <p className="text-brand-blue/70 text-sm">£1.00 per story</p>
                </div>
                <div onClick={handleCreditClick} className="text-center p-4 bg-brand-cream rounded-xl border-2 border-brand-orange cursor-pointer transition-all hover:shadow-lg hover:scale-105 hover:bg-brand-cream/80">
                  <Badge className="bg-brand-orange text-white mb-2">Most Popular</Badge>
                  <h4 className="font-bold text-brand-blue text-lg">10 Credits</h4>
                  <p className="text-brand-blue text-2xl font-bold">£8.99</p>
                  <p className="text-brand-blue/70 text-sm">£0.90 per story</p>
                </div>
                <div onClick={handleCreditClick} className="text-center p-4 bg-brand-cream rounded-xl border-2 border-brand-teal cursor-pointer transition-all hover:shadow-lg hover:scale-105 hover:bg-brand-cream/80">
                  <Badge className="bg-brand-blue text-white mb-2">Best Value</Badge>
                  <h4 className="font-bold text-brand-blue text-lg">20 Credits</h4>
                  <p className="text-brand-blue text-2xl font-bold">£15.99</p>
                  <p className="text-brand-blue/70 text-sm">£0.80 per story</p>
                </div>
              </div>

              <div className="mt-8 text-center">
                <h4 className="font-bold text-brand-blue mb-4">How Credits Work</h4>
                <div className="grid sm:grid-cols-2 gap-6 text-left">
                  <ul className="space-y-2">
                    <li className="flex items-start">
                      <CheckCircle className="w-4 h-4 text-brand-aqua mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-sm text-brand-blue">Only available to Premium & Ultimate subscribers</span>
                    </li>
                    <li className="flex items-start">
                      <CheckCircle className="w-4 h-4 text-brand-aqua mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-sm text-brand-blue">Automatically used when monthly limit exceeded</span>
                    </li>
                    <li className="flex items-start">
                      <CheckCircle className="w-4 h-4 text-brand-aqua mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-sm text-brand-blue">Never expire - use them anytime</span>
                    </li>
                  </ul>
                  <ul className="space-y-2">
                    <li className="flex items-start">
                      <CheckCircle className="w-4 h-4 text-brand-aqua mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-sm text-brand-blue">Features match your subscription tier</span>
                    </li>
                    <li className="flex items-start">
                      <CheckCircle className="w-4 h-4 text-brand-aqua mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-sm text-brand-blue">Perfect for busy months or special occasions</span>
                    </li>
                    <li className="flex items-start">
                      <CheckCircle className="w-4 h-4 text-brand-aqua mr-2 mt-0.5 flex-shrink-0" />
                      <span className="text-sm text-brand-blue">Upgrade subscription to enhance existing credits</span>
                    </li>
                  </ul>
                </div>
                {showCreditError && userData?.subscriptionTier === 'free' && (
                  <div className="mt-6 bg-red-50 border border-red-200 p-4 rounded-lg">
                    <p className="text-sm text-red-700 font-medium mb-2">
                      Credits Not Available for Free Users
                    </p>
                    <p className="text-sm text-red-600">
                      Only Premium and Ultimate subscribers can purchase extra credits. Please upgrade your subscription below to access the credit system.
                    </p>
                  </div>
                )}
                <div className="mt-6 bg-brand-cream p-4 rounded-lg">
                  <p className="text-sm text-brand-blue">
                    <strong>Note:</strong> Free users cannot purchase credits. Upgrade to Premium or Ultimate to access the credit system for additional stories.
                  </p>
                </div>
              </div>
            </CardContent>
          </Card>
        </div>
      </section>

      {/* Exceptional Value for Money */}
      <section className="py-16 bg-white/50">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="title-primary text-3xl lg:text-4xl text-brand-blue mb-4">
              Exceptional Value for Money
            </h2>
            <p className="body-text text-lg text-brand-orange">
              Why we believe that every story is a worthwhile investment in your child's future
            </p>
          </div>

          <Card className="cloud-shape bg-gradient-to-br from-brand-cream/30 to-brand-teal/10 mb-12">
            <CardContent className="p-8">
              <div className="grid md:grid-cols-3 gap-8 text-center">
                <div>
                  <div className="w-16 h-16 bg-brand-orange/20 rounded-full flex items-center justify-center mx-auto mb-4">
                    <Heart className="w-8 h-8 text-brand-orange" />
                  </div>
                  <h3 className="font-bold text-brand-purple mb-2">Incredible Value</h3>
                  <p className="text-brand-blue text-sm">
                    Less than £0.30 per story with our Premium plan (10 stories for £2.99/month)
                  </p>
                </div>

                <div>
                  <div className="w-16 h-16 bg-brand-teal/20 rounded-full flex items-center justify-center mx-auto mb-4">
                    <Download className="w-8 h-8 text-brand-teal" />
                  </div>
                  <h3 className="font-bold text-brand-purple mb-2">Keep Forever</h3>
                  <p className="text-brand-blue text-sm">
                    Unlike subscription services that lock content away, your stories are yours to <strong>keep forever</strong> - download beautiful PDFs and MP3 audio files that never expire
                  </p>
                </div>

                <div>
                  <div className="w-16 h-16 bg-brand-aqua/20 rounded-full flex items-center justify-center mx-auto mb-4">
                    <Users className="w-8 h-8 text-brand-aqua" />
                  </div>
                  <h3 className="font-bold text-brand-purple mb-2">Personalised Magic</h3>
                  <p className="text-brand-blue text-sm">
                    Your child becomes the hero of every adventure, a story as unique and magical as they are
                  </p>
                </div>
              </div>
            </CardContent>
          </Card>

          <div className="text-center mb-8">
            <h3 className="text-2xl font-bold text-brand-blue mb-2">
              Payment & Billing Details
            </h3>
            <p className="body-text text-brand-orange">
              Everything you need to know about our simple subscription model
            </p>
          </div>

          <div className="grid md:grid-cols-2 gap-8">
            <Card className="cloud-shape">
              <CardContent className="p-6">
                <div className="flex items-center mb-4">
                  <Calendar className="w-6 h-6 text-brand-orange mr-3" />
                  <h3 className="text-lg font-bold text-brand-blue">Billing Frequency</h3>
                </div>
                <ul className="space-y-3 text-brand-blue">
                  <li>• Premium: £2.99/month (10 stories monthly)</li>
                  <li>• Ultimate: £3.99/month (everything + audio)</li>
                  <li>• Automatically renews each month</li>
                  <li>• First payment processed immediately</li>
                  <li>• No refunds for partial billing periods</li>
                </ul>
              </CardContent>
            </Card>

            <Card className="cloud-shape">
              <CardContent className="p-6">
                <div className="flex items-center mb-4">
                  <CreditCard className="w-6 h-6 text-brand-teal mr-3" />
                  <h3 className="text-lg font-bold text-brand-blue">Payment Methods</h3>
                </div>
                <ul className="space-y-3 text-brand-blue">
                  <li>• All major credit and debit cards</li>
                  <li>• Visa, Mastercard, American Express</li>
                  <li>• Secure processing via Stripe</li>
                  <li>• No payment details stored on our servers</li>
                  <li>• Update payment method anytime</li>
                </ul>
              </CardContent>
            </Card>

            <Card className="cloud-shape">
              <CardContent className="p-6">
                <div className="flex items-center mb-4">
                  <Shield className="w-6 h-6 text-brand-aqua mr-3" />
                  <h3 className="text-lg font-bold text-brand-blue">Cancellation Policy</h3>
                </div>
                <ul className="space-y-3 text-brand-blue">
                  <li>• Cancel anytime with no penalties</li>
                  <li>• No long-term contracts required</li>
                  <li>• Access continues until end of billing period</li>
                  <li>• Instant cancellation from your account</li>
                  <li>• Re-subscribe anytime if you change your mind</li>
                </ul>
              </CardContent>
            </Card>

            <Card className="cloud-shape">
              <CardContent className="p-6">
                <div className="flex items-center mb-4">
                  <Clock className="w-6 h-6 text-brand-orange mr-3" />
                  <h3 className="text-lg font-bold text-brand-blue">Usage Limits</h3>
                </div>
                <ul className="space-y-3 text-brand-blue">
                  <li>• Free plan: 2 stories per month</li>
                  <li>• Premium: 10 stories per month</li>
                  <li>• Ultimate: 10 stories per month</li>
                  <li>• Create stories for multiple children</li>
                  <li>• Monthly limits reset on billing date</li>
                </ul>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Important Notes */}
      <section className="py-16 bg-white">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8">
          <Card className="cloud-shape border-l-4 border-brand-orange">
            <CardContent className="p-6">
              <div className="flex items-start">
                <AlertCircle className="w-6 h-6 text-brand-orange mr-4 mt-1 flex-shrink-0" />
                <div>
                  <h3 className="font-bold text-brand-blue mb-3">Important Information</h3>
                  <ul className="space-y-2 text-brand-blue text-sm">
                    <li>• Download your 2 free stories to keep them forever - no payment information required</li>
                    <li>• Premium subscription starts immediately upon payment confirmation</li>
                    <li>• Premium/Ultimate subscribers: All stories remain accessible in your library even after cancellation</li>
                    <li>• Downloaded PDFs are yours to keep forever</li>
                    <li>• Prices shown in British Pounds (GBP) and may vary by region</li>
                    <li>• VAT/taxes may apply based on your location</li>
                    <li>• Customer support available for all billing questions</li>
                  </ul>
                </div>
              </div>
            </CardContent>
          </Card>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-16 bg-gradient-to-r from-brand-blue to-brand-aqua text-white">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <h2 className="title-secondary text-3xl lg:text-4xl mb-4">
            Ready to Start Creating Magical Stories?
          </h2>
          <p className="body-text text-xl mb-8 opacity-90">
            Join thousands of families already creating personalised bedtime adventures!
          </p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center">
            <div className="flex flex-col items-center">
              <Link href="/login?tab=register">
                <Button 
                  size="lg"
                  className="bg-white text-brand-blue hover:bg-gray-100 px-8 py-4 rounded-full font-semibold text-lg"
                >
                  <Sparkles className="w-5 h-5 mr-2" />
                  Start with Free Story
                </Button>
              </Link>
              <p className="text-sm text-white/80 mt-2 font-medium">
                No payment or card details required
              </p>
            </div>
            <Link href={user ? "/subscribe" : "/login?tab=register"}>
              <Button 
                size="lg"
                className="bg-white text-brand-blue hover:bg-gray-100 px-8 py-4 rounded-full font-semibold text-lg"
              >
                <Crown className="w-5 h-5 mr-2" />
                Subscribe Now
              </Button>
            </Link>
          </div>
        </div>
      </section>
    </div>
  );
}